Signed-off-by: Adolf Belka <[email protected]>
---
 config/backup/backup.pl | 6 +++++-
 1 file changed, 5 insertions(+), 1 deletion(-)

diff --git a/config/backup/backup.pl b/config/backup/backup.pl
index e79f510c6..8988427ea 100644
--- a/config/backup/backup.pl
+++ b/config/backup/backup.pl
@@ -349,8 +349,12 @@ restore_backup() {
                rm /var/log/pakfire.log
        fi
 
        # Update the OpenVPN configuration and restart the openvpn daemons
collectd.vpn
+       # if it is the old name and restart the openvpn daemons
        sudo -u nobody /srv/web/ipfire/cgi-bin/ovpnmain.cgi
+       if grep -q "/var/run/ovpnserver.log" /var/ipfire/ovpn/collectd.vpn; then
+               sed -i 's|"/var/run/ovpnserver.log"|"/var/run/openvpn-rw.log"|' 
/var/ipfire/ovpn/collectd.vpn
+       fi
        /etc/init.d/openvpn-n2n restart
        /etc/init.d/openvpn-rw restart
 
@@ -349,8 +349,12 @@ restore_backup() {
        fi
 
-       # Update the OpenVPN configuration and restart the openvpn daemons
+       # Update the OpenVPN configuration, update the RW log entry in 
collectd.vpn
-- 
2.51.0


Reply via email to